.. _github-stats-3-7-1:

GitHub statistics for 3.7.1 (Mar 03, 2023)
==========================================

GitHub statistics for 2023/02/13 (tag: v3.7.0) - 2023/03/03

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 14 issues and merged 62 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/80?closed=1>`__

The following 16 authors contributed 129 commits.

* Albert Y. Shih
* Antony Lee
* devRD
* Elliott Sales de Andrade
* Fabian Joswig
* Greg Lucas
* Hasan Rashid
* hasanrashid
* Jody Klymak
* Kyle Sunden
* Oscar Gustafsson
* Ratnabali Dutta
* RishabhSpark
* Ruth Comer
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (62):

* :ghpull:`25377`: Backport PR #25372 on branch v3.7.x (Clean up Curve ArrowStyle docs)
* :ghpull:`25376`: Backport PR #25371 on branch v3.7.x (Tk: Fix size of spacers when changing display DPI)
* :ghpull:`25375`: Backport PR #25364 on branch v3.7.x (BLD: Pre-download Qhull license to put in wheels)
* :ghpull:`25372`: Clean up Curve ArrowStyle docs
* :ghpull:`25371`: Tk: Fix size of spacers when changing display DPI
* :ghpull:`25364`: BLD: Pre-download Qhull license to put in wheels
* :ghpull:`25370`: Backport PR#25369: Pin sphinx themes more strictly
* :ghpull:`25368`: Backport PR #25339 on branch v3.7.x (Disable discarded animation warning on save)
* :ghpull:`25369`: Pin sphinx themes more strictly
* :ghpull:`25339`: Disable discarded animation warning on save
* :ghpull:`25354`: Backport PR #25353 on branch v3.7.x (link to ipympl docs instead of github)
* :ghpull:`25307`: Pin mpl-sphinx-theme on the v3.7.x branch
* :ghpull:`25350`: Backport PR #25346 on branch v3.7.x (FIX: use wrapped text in Text._get_layout)
* :ghpull:`25348`: Backport PR #25325 on branch v3.7.x (Clean up legend loc parameter documentation)
* :ghpull:`25325`: Clean up legend loc parameter documentation
* :ghpull:`25346`: FIX: use wrapped text in Text._get_layout
* :ghpull:`25343`: Backport PR #25340 on branch v3.7.x (Fix RangeSlider.set_val when outside existing value)
* :ghpull:`25342`: Backport PR #25341 on branch v3.7.x (TST: Increase test_set_line_coll_dash_image tolerance slightly.)
* :ghpull:`25340`: Fix RangeSlider.set_val when outside existing value
* :ghpull:`25341`: TST: Increase test_set_line_coll_dash_image tolerance slightly.
* :ghpull:`25337`: Backport PR #25311 on branch v3.7.x (Make draggable legends picklable.)
* :ghpull:`25311`: Make draggable legends picklable.
* :ghpull:`25331`: Backport PR #25327 on branch v3.7.x (Fix doc-string issues identified by velin)
* :ghpull:`25327`: Fix doc-string issues identified by velin
* :ghpull:`25321`: Backport PR #25320 on branch v3.7.x (DOC: fix typo)
* :ghpull:`25319`: Backport PR #25305 on branch v3.7.x (DOC: add layout='none' option to Figure constructor)
* :ghpull:`25305`: DOC: add layout='none' option to Figure constructor
* :ghpull:`25315`: Backport PR #24878 on branch v3.7.x ( [Doc]: Add alt-text to images in 3.6 release notes #24844 )
* :ghpull:`24878`: [Doc]: Add alt-text to images in 3.6 release notes #24844
* :ghpull:`25312`: Backport PR #25308 on branch v3.7.x (DOC: add include source to a 3.7 what's new)
* :ghpull:`25309`: Backport PR #25302 on branch v3.7.x (Cleanup gradient_bar example.)
* :ghpull:`25299`: Backport PR #25238 on branch v3.7.x (Check file path for animation and raise if it does not exist)
* :ghpull:`25297`: Backport PR #25295 on branch v3.7.x (Increase timeout for interactive backend tests)
* :ghpull:`25238`: Check file path for animation and raise if it does not exist
* :ghpull:`25295`: Increase timeout for interactive backend tests
* :ghpull:`25288`: Backport PR #25279 on branch v3.7.x (Fix Lasso line cleanup)
* :ghpull:`25294`: Backport PR #25278 on branch v3.7.x (Revert #23417 (Consistently set label on axis with units))
* :ghpull:`25293`: Backport PR #25155 on branch v3.7.x (Fix lasso unresponsive issue by adding a lock release event)
* :ghpull:`25289`: Backport PR #25286 on branch v3.7.x (DOC: add cache-busting query to switcher json url)
* :ghpull:`25278`: Revert #23417 (Consistently set label on axis with units)
* :ghpull:`25155`: Fix lasso unresponsive issue by adding a lock release event
* :ghpull:`25285`: Backport PR #25280 on branch v3.7.x (Fix setting CSS with latest GTK4)
* :ghpull:`25279`: Fix Lasso line cleanup
* :ghpull:`25284`: Backport PR #25283 on branch v3.7.x (CI: unpin reviewdog eslint)
* :ghpull:`25280`: Fix setting CSS with latest GTK4
* :ghpull:`25283`: CI: unpin reviewdog eslint
* :ghpull:`25277`: Backport PR #25268 on branch v3.7.x (Fix import of styles with relative path)
* :ghpull:`25276`: Backport PR #25237 on branch v3.7.x (Fixed a bug where rcParams settings were being ignored for formatting axes labels)
* :ghpull:`25237`: Fixed a bug where rcParams settings were being ignored for formatting axes labels
* :ghpull:`25268`: Fix import of styles with relative path
* :ghpull:`25264`: Backport PR #25262 on branch v3.7.x (CI: Pin reviewdog eslint to use node 18.13)
* :ghpull:`25245`: Backport PR #25236: Re-enable CI buildwheel and cygwin labels
* :ghpull:`25262`: CI: Pin reviewdog eslint to use node 18.13
* :ghpull:`25260`: Backport PR #25234 on branch v3.7.x (added layout="compressed" for pyplot #25223)
* :ghpull:`25234`: added layout="compressed" for pyplot #25223
* :ghpull:`25246`: Backport PR #25240 on branch v3.7.x (Avoid calling vars() on arbitrary third-party manager_class.)
* :ghpull:`25240`: Avoid calling vars() on arbitrary third-party manager_class.
* :ghpull:`25236`: Re-enable CI buildwheel and cygwin labels
* :ghpull:`25217`: Backport PR #25213 on branch v3.7.x (DOC: correct default value of pcolormesh shading)
* :ghpull:`25213`: DOC: correct default value of pcolormesh shading
* :ghpull:`25215`: Backport PR #25198 - DOC: remove constrained_layout kwarg from examples
* :ghpull:`25198`: DOC: remove constrained_layout kwarg from examples

Issues (14):

* :ghissue:`25361`: [Doc]: matplotlib.patches.ArrowStyle
* :ghissue:`25365`: [Bug]: Inconsistent size/padx for spacers in NavigationToolbar2Tk._rescale and _Spacer
* :ghissue:`25212`: [Bug]: LICENSE_QHULL is included in wheel only the second time
* :ghissue:`25323`: [Doc]: Misleading Figure.legend() options, loc='best' is not valid.
* :ghissue:`25336`: [Bug]: constrained layout with wrapped titles
* :ghissue:`25338`: [Bug]: set_val of rangeslider sets incorrect value
* :ghissue:`25300`: [Bug]: Unable to pickle figure with draggable legend
* :ghissue:`25223`: [Doc]: ``layout="none"`` for figure constructor?
* :ghissue:`25219`: [Bug]: axes.set_xlim with string dates raises when plotting with datetimes
* :ghissue:`21666`: [Doc]: Sidebar not always very helpful
* :ghissue:`25298`: [Bug]: ``axes.labelsize`` is ignored
* :ghissue:`25233`: [MNT]: FFMpegWriter does not check if out path exists when initialized.
* :ghissue:`25242`: [Bug]: Relative paths in ``plt.style.use()`` no longer work in 3.7
* :ghissue:`25251`: [CI]: eslint failure
